==> lms-1.8.0rc5.tar.gz: lms/modules/userpasswd.php <==
<?php

/*
 * LMS version 1.8.0rc5 Rosha
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: userpasswd.php,v 1.1.2.1 2005/12/07 08:56:22 alec Exp $
 */

$id = (isset($_GET['id'])) ? $_GET['id'] : $AUTH->id;

if($LMS->UserExists($id))
{
	$error = FALSE;

	if(isset($_POST['passwd']))
	{
		$passwd = $_POST['passwd'];
		
		if($passwd['passwd'] == '' || $passwd['confirm'] == '')
			$error['password'] = trans('Empty passwords are not allowed!').'<BR>';
		
		if($passwd['passwd'] != $passwd['confirm'])
			$error['password'] = trans('Passwords does not match!');
		
		if(!$error)
		{
			$LMS->SetUserPassword($id, $passwd['passwd']);
			header('Location: ?'. $SESSION->get('backto'));
		}
	}

	$passwd['realname'] = $LMS->GetUserName($id);
	$passwd['id'] = $id;
	$layout['pagetitle'] = trans('Password Change for User $0',$passwd['realname']);
	$SMARTY->assign('error', $error);
	$SMARTY->assign('passwd', $passwd);
	$SMARTY->display('userpasswd.html');

}
else
{
	$SESSION->redirect('?m='. $SESSION->get('lastmodule'));
}

?>

==> lms-1.10.2.tar.gz: lms/modules/userpasswd.php <==
<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: userpasswd.php,v 1.6.2.1 2007/08/17 13:15:28 alec Exp $
 */

$id = (isset($_GET['id'])) ? $_GET['id'] : $AUTH->id;

if($LMS->UserExists($id))
{
	if(isset($_POST['passwd']))
	{
		$passwd = $_POST['passwd'];
		
		if($passwd['passwd'] == '' || $passwd['confirm'] == '')
			$error['password'] = trans('Empty passwords are not allowed!').'<BR>';
		
		if($passwd['passwd'] != $passwd['confirm'])
			$error['password'] = trans('Passwords does not match!');
		
		if(!$error)
		{
			$LMS->SetUserPassword($id, $passwd['passwd']);
			header('Location: ?'. $SESSION->get('backto'));
		}
	}

	$passwd['id'] = $id;

	$layout['pagetitle'] = trans('Password Change for User $0', $DB->GetOne('SELECT name FROM users WHERE id = ?', array($id)));

	$SMARTY->assign('error', $error);
	$SMARTY->assign('passwd', $passwd);
	$SMARTY->display('userpasswd.html');
}
else
{
	$SESSION->redirect('?m='. $SESSION->get('lastmodule'));
}

?>
